@@ -1,8 +1,8 @@
 """
 Primitive atomic and molecular objects for pygamlab.
 """
-from .gam_atom import GAM_Atom
-from .gam_bond import GAM_Bond
+from .gam_universe import GAM_Atom
+from .gam_universe import GAM_Bond
 from .gam_molecule import GAM_Molecule
 
 
