@@ -1,6 +1,6 @@
 
-from .gam_atom import GAM_Atom 
-from .gam_bond import GAM_Bond
+from .gam_universe import GAM_Atom 
+from .gam_universe import GAM_Bond
 
 
 
